ondrs.barcode


generateclj

(generate type code & args)
source

image-formatclj

(image-format file)

Gets the file extension and validates it

Gets the file extension and validates it
sourceraw docstring

write!clj

(write! barcode output-file)
(write! barcode output-stream format)

Writes the generated barcode into a file our into an output stream

Writes the generated barcode into a file our into an output stream
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries